@@ -493,6 +493,15 @@ class VariableOsDeviceSize(ReadonlyVariable):
         return map(humanreadableSize,
                    self.Get())
 
+#############################################
+# Minimal bios boot size
+#############################################
+
+class VariableClMinimumBiosGrubSize(Variable):
+    """
+    Минимальный размер раздела bios_grub
+    """
+    value = str(9 * Sizes.M)
 
 #############################################
 # Disk variables
@@ -2224,7 +2233,7 @@ class VariableOsInstallMbr(LocationHelper, Variable):
                     )
                     if disk_id == 'EF02' and mbrDisk in disk_parent
                 )
-                bios_grub_size = self.Get('cl_autopartition_bios_grub_size')
+                bios_grub_size = self.Get('cl_minimum_bios_grub_size')
                 for bbsize in bbsizes:
                     minsize = "%dMb" % (int(bios_grub_size) / Sizes.M)
                     if not bbsize:
